@@ -60,16 +60,17 @@ These datatypes are parsed but not supported:
 
 """
 
-__docformat__   = "epytext en"
+__docformat__ = 'epytext en'
 
 from pyrad import bidict
 from pyrad import tools
 from pyrad import dictfile
 from copy import copy
 
-DATATYPES = frozenset(["string", "ipaddr", "integer", "date",
-                       "octets", "abinary", "ipv6addr",
-                       "ipv6prefix", "ifid", "ether"])
+DATATYPES = frozenset(['string', 'ipaddr', 'integer', 'date',
+                       'octets', 'abinary', 'ipv6addr',
+                       'ipv6prefix', 'ifid', 'ether'])
+
 
 class ParseError(Exception):
     """Dictionary parser exceptions.
@@ -81,41 +82,42 @@ class ParseError(Exception):
     """
 
     def __init__(self, msg=None, **data):
-        self.msg=msg
+        self.msg = msg
         self.file = data.get('file', '')
         self.line = data.get('line', -1)
 
     def __str__(self):
-        str=""
+        str = ''
         if self.file:
-            str+=self.file
+            str += self.file
         if self.line > -1:
-            str+="(%d)" % self.line
+            str += '(%d)' % self.line
         if self.file or self.line > -1:
-            str+=": "
-        str+="Parse error"
+            str += ': '
+        str += 'Parse error'
         if self.msg:
-            str+=": %s" % self.msg
+            str += ': %s' % self.msg
 
         return str
 
 
 class Attribute:
-    def __init__(self, name, code, datatype, vendor="", values={}, encrypt=0, has_tag=False):
+    def __init__(self, name, code, datatype, vendor='', values={},
+            encrypt=0, has_tag=False):
         if datatype not in DATATYPES:
-            raise ValueError, "Invalid data type"
-        self.name=name
-        self.code=code
-        self.type=datatype
-        self.vendor=vendor
-        self.encrypt=encrypt
-        self.has_tag=has_tag
-        self.values=bidict.BiDict()
-        for (key,value) in values.items():
+            raise ValueError('Invalid data type')
+        self.name = name
+        self.code = code
+        self.type = datatype
+        self.vendor = vendor
+        self.encrypt = encrypt
+        self.has_tag = has_tag
+        self.values = bidict.BiDict()
+        for (key, value) in values.items():
             self.values.Add(key, value)
 
 
-class Dictionary:
+class Dictionary(object):
     """RADIUS dictionary class.
     This class stores all information about vendors, attributes and their
     values as defined in RADIUS dictionary files.
@@ -135,10 +137,10 @@ class Dictionary:
         :param dicts: list of dictionaries
         :type dicts:  sequence of strings or files
         """
-        self.vendors=bidict.BiDict()
-        self.vendors.Add("", 0)
-        self.attrindex=bidict.BiDict()
-        self.attributes={}
+        self.vendors = bidict.BiDict()
+        self.vendors.Add('', 0)
+        self.attrindex = bidict.BiDict()
+        self.attributes = {}
         self.defer_parse = []
 
         if dict:
@@ -147,162 +149,156 @@ class Dictionary:
         for i in dicts:
             self.ReadDictionary(i)
 
-
     def __len__(self):
         return len(self.attributes)
 
-
     def __getitem__(self, key):
         return self.attributes[key]
 
-
     def __contains__(self, key):
         return key in self.attributes
 
-
-    def has_key(self, key):
-        return self.attributes.has_key(key)
-
+    has_key = __contains__
 
     def __ParseAttribute(self, state, tokens):
-        if not len(tokens) in [4,5]:
+        if not len(tokens) in [4, 5]:
             raise ParseError(
-                "Incorrect number of tokens for attribute definition",
-                name=state["file"],
-                line=state["line"])
+                'Incorrect number of tokens for attribute definition',
+                name=state['file'],
+                line=state['line'])
 
-        vendor=state["vendor"]
+        vendor = state['vendor']
         has_tag = False
         encrypt = 0
-        if len(tokens)>=5:
+        if len(tokens) >= 5:
             def keyval(o):
                 kv = o.split('=')
-                if len(kv)==2:
+                if len(kv) == 2:
                     return (kv[0], kv[1])
                 else:
                     return (kv[0], None)
             options = [keyval(o) for o in tokens[4].split(',')]
-            for key,val in options:
+            for (key, val) in options:
                 if key == 'has_tag':
                     has_tag = True
                 elif key == 'encrypt':
-                    if val not in ['1','2','3']:
-                        raise ParseError("Illegal attribute encryption: " + val,
-                                         file = state["file"],
-                                         line = state["line"])
+                    if val not in ['1', '2', '3']:
+                        raise ParseError(
+                                'Illegal attribute encryption: %s' % val,
+                                file=state['file'],
+                                line=state['line'])
                     encrypt = int(val)
 
-            if (not has_tag) and encrypt==0:
-                vendor=tokens[4]
+            if (not has_tag) and encrypt == 0:
+                vendor = tokens[4]
                 if not self.vendors.HasForward(vendor):
-                    raise ParseError("Unknown vendor " + vendor,
-                                     file = state["file"],
-                                     line = state["line"])
+                    raise ParseError('Unknown vendor ' + vendor,
+                                     file=state['file'],
+                                     line=state['line'])
 
-        (attribute,code,datatype)=tokens[1:4]
-        code=int(code, 0)
+        (attribute, code, datatype) = tokens[1:4]
+        code = int(code, 0)
         if not datatype in DATATYPES:
-            raise ParseError("Illegal type: " + datatype,
-                             file = state["file"],
-                             line = state["line"])
+            raise ParseError('Illegal type: ' + datatype,
+                             file=state['file'],
+                             line=state['line'])
 
         if vendor:
-            key=(self.vendors.GetForward(vendor),code)
+            key = (self.vendors.GetForward(vendor), code)
         else:
-            key=code
+            key = code
 
         self.attrindex.Add(attribute, key)
-        self.attributes[attribute]=Attribute(attribute, code, datatype, vendor,
-                                             encrypt=encrypt, has_tag=has_tag)
-
+        self.attributes[attribute] = Attribute(attribute, code, datatype,
+                vendor, encrypt=encrypt, has_tag=has_tag)
 
     def __ParseValue(self, state, tokens, defer):
-        if len(tokens)!=4:
-            raise ParseError("Incorrect number of tokens for value definition",
-                             file = state["file"],
-                             line = state["line"])
+        if len(tokens) != 4:
+            raise ParseError('Incorrect number of tokens for value definition',
+                             file=state['file'],
+                             line=state['line'])
 
-        (attr, key, value)=tokens[1:]
+        (attr, key, value) = tokens[1:]
 
         try:
-            adef=self.attributes[attr]
+            adef = self.attributes[attr]
         except KeyError:
             if defer:
                 self.defer_parse.append((copy(state), copy(tokens)))
                 return
-            raise ParseError("Value defined for unknown attribute " + attr,
-                             file = state["file"],
-                             line = state["line"])
+            raise ParseError('Value defined for unknown attribute ' + attr,
+                             file=state['file'],
+                             line=state['line'])
 
-        if adef.type=="integer":
-            value=int(value, 0)
-        value=tools.EncodeAttr(adef.type, value)
+        if adef.type == 'integer':
+            value = int(value, 0)
+        value = tools.EncodeAttr(adef.type, value)
         self.attributes[attr].values.Add(key, value)
 
-
     def __ParseVendor(self, state, tokens):
         if len(tokens) not in [3, 4]:
-            raise ParseError("Incorrect number of tokens for vendor definition",
-                             file = state["file"],
-                             line = state["line"])
+            raise ParseError(
+                    'Incorrect number of tokens for vendor definition',
+                    file=state['file'],
+                    line=state['line'])
 
         # Parse format specification, but do
         # nothing about it for now
-        format = (1, 1)
         if len(tokens) == 4:
             fmt = tokens[3].split('=')
             if fmt[0] != 'format':
-                raise ParseError("Unknown option '%s' for vendor definition" % (fmt[0]),
-                                 file = state["file"],
-                                 line = state["line"])
+                raise ParseError(
+                        "Unknown option '%s' for vendor definition" % (fmt[0]),
+                        file=state['file'],
+                        line=state['line'])
             try:
-                t,l = tuple(int(a) for a in fmt[1].split(','))
-                format = (t,l)
+                (t, l) = tuple(int(a) for a in fmt[1].split(','))
                 if t not in [1, 2, 4] or l not in [0, 1, 2]:
-                    raise ParseError("Unknown vendor format specification '%s" % (fmt[1]),
-                                     file = state["file"],
-                                     line = state["line"])
+                    raise ParseError(
+                        'Unknown vendor format specification %s' % (fmt[1]),
+                        file=state['file'],
+                        line=state['line'])
             except ValueError:
-                raise ParseError("Syntax error in vendor specification",
-                                 file = state["file"],
-                                 line = state["line"])
+                raise ParseError(
+                        'Syntax error in vendor specification',
+                        file=state['file'],
+                        line=state['line'])
 
-        (vendorname,vendor)=tokens[1:3]
+        (vendorname, vendor) = tokens[1:3]
         self.vendors.Add(vendorname, int(vendor, 0))
 
-
     def __ParseBeginVendor(self, state, tokens):
-        if len(tokens)!=2:
-            raise ParseError("Incorrect number of tokens for begin-vendor statement",
-                             file = state["file"],
-                             line = state["line"])
+        if len(tokens) != 2:
+            raise ParseError(
+                    'Incorrect number of tokens for begin-vendor statement',
+                    file=state['file'],
+                    line=state['line'])
 
-        vendor=tokens[1]
+        vendor = tokens[1]
 
         if not self.vendors.HasForward(vendor):
-            raise ParseError("Unknown vendor %s in begin-vendor statement" % vendor,
-                             file = state["file"],
-                             line = state["line"])
-
-        state["vendor"]=vendor
+            raise ParseError(
+                    'Unknown vendor %s in begin-vendor statement' % vendor,
+                    file=state['file'],
+                    line=state['line'])
 
+        state['vendor'] = vendor
 
     def __ParseEndVendor(self, state, tokens):
-        if len(tokens)!=2:
+        if len(tokens) != 2:
             raise ParseError(
-                "Incorrect number of tokens for end-vendor statement",
-                file = state["file"],
-                line = state["line"])
+                'Incorrect number of tokens for end-vendor statement',
+                file=state['file'],
+                line=state['line'])
 
+        vendor = tokens[1]
 
-        vendor=tokens[1]
-
-        if state["vendor"]!=vendor:
-            raise ParseError("Ending non-open vendor" + vendor,
-                             file = state["file"],
-                             line = state["line"])
-
-        state["vendor"]=""
+        if state['vendor'] != vendor:
+            raise ParseError(
+                    'Ending non-open vendor' + vendor,
+                    file=state['file'],
+                    line=state['line'])
+        state['vendor'] = ''
 
     def ReadDictionary(self, file):
         """Parse a dictionary file.
@@ -315,34 +311,33 @@ class Dictionary:
 
         fil = dictfile.DictFile(file)
 
-        state={}
-        state["vendor"]=""
+        state = {}
+        state['vendor'] = ''
 
         self.defer_parse = []
         for line in fil:
-            state["file"]=fil.File()
-            state["line"]=fil.Line()
-            line=line.split("#", 1)[0].strip()
+            state['file'] = fil.File()
+            state['line'] = fil.Line()
+            line = line.split('#', 1)[0].strip()
 
-            tokens=line.split()
+            tokens = line.split()
             if not tokens:
                 continue
 
             key = tokens[0].upper()
-            if key=="ATTRIBUTE":
+            if key == 'ATTRIBUTE':
                 self.__ParseAttribute(state, tokens)
-            elif key=="VALUE":
+            elif key == 'VALUE':
                 self.__ParseValue(state, tokens, True)
-            elif key=="VENDOR":
+            elif key == 'VENDOR':
                 self.__ParseVendor(state, tokens)
-            elif key=="BEGIN-VENDOR":
+            elif key == 'BEGIN-VENDOR':
                 self.__ParseBeginVendor(state, tokens)
-            elif key=="END-VENDOR":
+            elif key == 'END-VENDOR':
                 self.__ParseEndVendor(state, tokens)
 
         for state, tokens in self.defer_parse:
             key = tokens[0].upper()
-            if key=="VALUE":
+            if key == 'VALUE':
                 self.__ParseValue(state, tokens, False)
         self.defer_parse = []
-
